@@ -9,16 +9,17 @@ import tempfile
 from time import sleep
 from uuid import uuid4
 
+from dandischema.consts import DANDI_SCHEMA_VERSION
 from dateutil.tz import tzutc
 import pynwb
 import pytest
 import requests
 
 from .skip import skipif
+from .. import get_logger
 from ..cli.command import organize
 from ..consts import dandiset_metadata_file, known_instances
 from ..dandiapi import DandiAPIClient
-from .. import get_logger
 from ..pynwb_utils import make_nwb_file, metadata_nwb_file_fields
 from ..upload import upload
 
@@ -181,6 +182,7 @@ def docker_compose_setup():
     env = dict(os.environ)
     env["DJANGO_DANDI_GIRDER_API_URL"] = "http://localhost:8080/api/v1"
     env["DJANGO_DANDI_GIRDER_API_KEY"] = "abc123"
+    env["DJANGO_DANDI_SCHEMA_VERSION"] = DANDI_SCHEMA_VERSION
 
     try:
         if create:
@@ -260,8 +262,7 @@ def local_dandi_api(docker_compose_setup):
     instance_id = "dandi-api-local-docker-tests"
     instance = known_instances[instance_id]
     api_key = docker_compose_setup["django_api_key"]
-    client = DandiAPIClient(api_url=instance.api, token=api_key)
-    with client.session():
+    with DandiAPIClient(api_url=instance.api, token=api_key) as client:
         yield {
             "api_key": api_key,
             "client": client,
@@ -272,9 +273,24 @@ def local_dandi_api(docker_compose_setup):
 
 @pytest.fixture()
 def text_dandiset(local_dandi_api, monkeypatch, tmp_path_factory):
-    dandiset_id = local_dandi_api["client"].create_dandiset("Text Dandiset", {})[
-        "identifier"
-    ]
+    d = local_dandi_api["client"].create_dandiset(
+        "Text Dandiset",
+        {
+            "schemaKey": "Dandiset",
+            "name": "Text Dandiset",
+            "description": "A test text Dandiset",
+            "contributor": [
+                {
+                    "schemaKey": "Person",
+                    "name": "Wodder, John",
+                    "roleName": ["dcite:Author", "dcite:ContactPerson"],
+                }
+            ],
+            "license": ["spdx:CC0-1.0"],
+            "manifestLocation": ["https://github.com/dandi/dandi-cli"],
+        },
+    )
+    dandiset_id = d.identifier
     dspath = tmp_path_factory.mktemp("text_dandiset")
     (dspath / dandiset_metadata_file).write_text(f"identifier: '{dandiset_id}'\n")
     (dspath / "file.txt").write_text("This is test text.\n")
@@ -301,6 +317,7 @@ def text_dandiset(local_dandi_api, monkeypatch, tmp_path_factory):
     return {
         "client": local_dandi_api["client"],
         "dspath": dspath,
+        "dandiset": d,
         "dandiset_id": dandiset_id,
         "reupload": upload_dandiset,
     }
