@@ -3,7 +3,7 @@ from pathlib import Path
 import pytest
 import requests
 
-from ..consts import dandiset_metadata_file
+from ..consts import DRAFT, dandiset_metadata_file
 from ..dandiapi import RESTFullAPIClient
 from ..delete import delete
 from ..download import download
@@ -137,7 +137,7 @@ def test_delete_dandiset(local_dandi_api, mocker, monkeypatch, text_dandiset, pa
     )
     delete_spy.assert_called()
     with pytest.raises(requests.HTTPError) as excinfo:
-        local_dandi_api["client"].get_dandiset(dandiset_id, "draft")
+        local_dandi_api["client"].get_dandiset(dandiset_id, DRAFT, lazy=False)
     assert excinfo.value.response.status_code == 404
 
 
@@ -378,6 +378,6 @@ def test_delete_no_dandiset(mocker, monkeypatch, tmp_path):
         )
     assert str(excinfo.value) == (
         f"Found no {dandiset_metadata_file} anywhere.  "
-        "Use 'dandi register', 'download', or 'organize' first"
+        "Use 'dandi download' or 'organize' first"
     )
     delete_spy.assert_not_called()
